/*
 * prefs.c: 
 * GTK+ UI preferences for Umix.
 *
 * Copyright (C) 2002 Sakari Lehtonen <sakari@ionstream.fi>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#include <gtk/gtk.h>
#include "umix_common.h"
#include "ui.h"
#include "support.h"
#include "prefs.h"

static GtkWidget *prefs_window = NULL;
	
/* check buttons */
static GtkWidget *show_rec_checkbutton;
static GtkWidget *show_bal_checkbutton;

static void cb_prefs_ok(GtkWidget *widget, gpointer data)
{
	/* GUI tab */
	gtk_config.show_record_button = gtk_toggle_button_get_active(
		GTK_TOGGLE_BUTTON(show_rec_checkbutton));
	gtk_config.show_balance_adj = gtk_toggle_button_get_active(
		GTK_TOGGLE_BUTTON(show_bal_checkbutton));

	update_stuff();
	cb_prefs_delete(NULL, NULL);
	return;
}

void cb_prefs_delete(GtkWidget *widget, gpointer data)
{
	gtk_widget_destroy(prefs_window);
	prefs_window = NULL;
}

void cb_show_prefs(GtkWidget *widget, gpointer data)
{
	GtkWidget *top_vbox;
	GtkWidget *checkbutton_vbox;
	GtkWidget *notebook;
	GtkWidget *view_frame;
	GtkWidget *gui_tab_label, *chan_tab_label;
	GtkWidget *label3;
	GtkWidget *ok_button, *cancel_button;
	GtkWidget *hbuttonbox;

	if( prefs_window != NULL )
	{
		gdk_window_raise(prefs_window->window);
		return;
	}

	prefs_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_wmclass(GTK_WINDOW(prefs_window), "prefs", "Umix");
	gtk_signal_connect(GTK_OBJECT(prefs_window), "delete_event", 
		GTK_SIGNAL_FUNC(cb_prefs_delete), NULL);

	gtk_window_set_title(GTK_WINDOW(prefs_window), _("Preferences - Umix"));
	gtk_window_set_policy(GTK_WINDOW(prefs_window), 
		NOSHRINK, NOGROW, NOAUTOGROW);
	gtk_window_set_position(GTK_WINDOW(prefs_window), GTK_WIN_POS_MOUSE);
	gtk_container_border_width(GTK_CONTAINER(prefs_window), 5);

	top_vbox = gtk_vbox_new(NONHOMOGENEOUS, 10);
	gtk_container_add(GTK_CONTAINER(prefs_window), top_vbox);

	notebook = gtk_notebook_new();
	gtk_box_pack_start(GTK_BOX(top_vbox), notebook, FILL, EXPAND, 0);

	/* GUI tab */
	view_frame = gtk_frame_new(_("View options"));
	gtk_container_add(GTK_CONTAINER(notebook), view_frame);
	gtk_container_set_border_width(GTK_CONTAINER(view_frame), 5);

	checkbutton_vbox = gtk_vbox_new(NONHOMOGENEOUS, 0);
	gtk_container_add(GTK_CONTAINER(view_frame), checkbutton_vbox);

	show_rec_checkbutton = gtk_check_button_new_with_label(_(
			"Show record buttons"));
	gtk_box_pack_start(GTK_BOX(checkbutton_vbox), show_rec_checkbutton, 
		NOEXPAND, NOFILL, 0);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(show_rec_checkbutton),
		gtk_config.show_record_button);

	show_bal_checkbutton = gtk_check_button_new_with_label(_(
			"Show balance adjustment"));
	gtk_box_pack_start(GTK_BOX(checkbutton_vbox), show_bal_checkbutton, 
		NOEXPAND, NOFILL, 0);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(show_bal_checkbutton),
		gtk_config.show_balance_adj);

	gui_tab_label = gtk_label_new ("GUI");
	gtk_notebook_set_tab_label(GTK_NOTEBOOK (notebook), 
		gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook), 0), 
		gui_tab_label);

	/* Channels tab */
	label3 = gtk_label_new("F00 BAR OWNZ J00 .. under construction");
	gtk_container_add(GTK_CONTAINER(notebook), label3);

	chan_tab_label = gtk_label_new(_("Channels"));
	gtk_notebook_set_tab_label(GTK_NOTEBOOK (notebook), 
		gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook), 1), 
		chan_tab_label);

	/* Ok and Cancel buttons */
	hbuttonbox = gtk_hbutton_box_new();
	gtk_box_pack_start(GTK_BOX(top_vbox), hbuttonbox, NOEXPAND, NOFILL, 0);
	gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox),GTK_BUTTONBOX_END);

	ok_button = gtk_button_new_from_stock(GTK_STOCK_OK);
	gtk_signal_connect(GTK_OBJECT(ok_button), "clicked",
		GTK_SIGNAL_FUNC(cb_prefs_ok), NULL);
	gtk_container_add(GTK_CONTAINER (hbuttonbox), ok_button);
	GTK_WIDGET_SET_FLAGS(ok_button, GTK_CAN_DEFAULT);

	cancel_button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
	gtk_signal_connect(GTK_OBJECT(cancel_button), "clicked",
		GTK_SIGNAL_FUNC(cb_prefs_delete), NULL);
	gtk_container_add(GTK_CONTAINER(hbuttonbox), cancel_button);
	GTK_WIDGET_SET_FLAGS (cancel_button, GTK_CAN_DEFAULT);

	gtk_widget_show_all(prefs_window);
}
